Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetTreeFileOid ¶
GetTreeFileOid returns the OID of the Tree File
func WriteTarArchiveFromRepository ¶
WriteTarArchiveFromRepository because yes
func WriteZipArchiveFromRepository ¶
WriteZipArchiveFromRepository as said
Types ¶
type TreeFiles ¶
type TreeFiles struct {
ID string
Path string
Content string
ContentB []byte
ContentH gotemplate.HTML
Size int64 // bytes
OverSize bool
IsBinary bool
OverPageSize bool
MimeType string
LineNos gotemplate.HTML
}
TreeFiles struct to get root tree without depth and contents
func GetTreeFileNoLimit ¶
GetTreeFileNoLimit yeah
func GetWalkTreeWithContent ¶
func GetWalkTreeWithContent(repo *git.Repository, path string) (finalEntries []TreeFiles, err error)
GetWalkTreeWithContent TreeFiles.Content will be nil if size is too big
Click to show internal directories.
Click to hide internal directories.